
/*
 *  tr.c
 *  Copyright (C) 1999 Brad Proctor
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* 
 * $Id: tr.c,v 1.2 1999/06/14 23:24:05 brad Exp $
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "version.h"

#define BUF_SIZE  65536

static char help_text[] =
{
   "Usage: tr [-cs] string1 string2\n"
   "       tr -s[-c] string1\n"
   "       tr -d[-c] string1\n"
   "       tr -ds[-c] string1 string2\n\n"
   "  -c         Complement characters in string1\n"
   "  -d         Delete all occurences of characters in string1\n"
   "  -s         Replace repeated characters with single characters.\n"
   "  --help     Print this help message\n"
   "  --version  Print the program version\n\n"
   "Report bugs to fredlie@sprynet.com"
   
};

static char buf[BUF_SIZE];
static char *string1;
static char *string2;
static char flag_complement = 0;
static char flag_replace = 0;
static char flag_delete = 0;

/*
 * Main
 */

int main(int argc, char **argv)
{
   int i;
   char *ptr;

   for(i = 1; i < argc; ++i)
   {
      ptr = argv[i];
      if(*ptr == '-')
      {
         while(*++ptr)
         switch(*ptr)
         {
            case '-':
               ++ptr;
               if(!strcmp(ptr, "help"))
               {
                  puts(help_text);
                  return (0);
               }
               else if(!strcmp(ptr, "version"))
               {
                  puts("tr (butils) "VERSION_STRING);
                  return (0);
               }
               else if(!string1)
                  string1 = argv[i];
               else if(!string2)
                  string2 = argv[i];
               else
               {
                  fprintf(stderr, "%s: Too many arguments.\n", argv[0]);
                  fputs("Try `tr --help' for more information.\n", stderr);
                  return (1);
               }
               break;
            case 'c': flag_complement = 1;   break;
            case 'd': flag_delete = 1;       break;
            case 's': flag_replace = 1;      break;
            default:
               if(!string1)
                  string1 = argv[i];
               else if(!string2)
                  string2 = argv[i];
               else
               {
                  fprintf(stderr, "%s: Too many arguments.\n", argv[0]);
                  fputs("Try `tr --help' for more information.\n", stderr);
                  return (1);
               }
         }
      }
      else if(!string1)
         string1 = argv[i];
      else if(!string2)
         string2 = argv[i];
      else
      {
         fprintf(stderr, "%s: Too many arguments.\n", argv[0]);
         fputs("Try `tr --help' for more information.\n", stderr);
         return (1);
      }
   }
   while(fread(buf, 1, BUF_SIZE, stdin) > 0)
   {
      ptr = buf;
      while(*ptr != 0)
      {
         ++ptr;
      }
   }
   return (0);
}